document.addEventListener('DOMContentLoaded', () => {
  const climber = document.querySelector('.climber');
  const altitudeDisplay = document.querySelector('.altitude');
  const maxScroll = document.documentElement.scrollHeight - window.innerHeight;
  let lastScrollPosition = 0;
  
  // Animation states for climber
  const animateClimber = (scrollDirection) => {
    const arms = document.querySelectorAll('.arm-left, .arm-right');
    const legs = document.querySelectorAll('.leg-left, .leg-right');
    
    arms.forEach(arm => {
      arm.style.transition = 'transform 0.3s ease-out';
      arm.style.transform = scrollDirection === 'up' 
        ? 'rotate(-45deg)' 
        : 'rotate(45deg)';
    });
    
    legs.forEach(leg => {
      leg.style.transition = 'transform 0.3s ease-out';
      leg.style.transform = scrollDirection === 'up' 
        ? 'rotate(45deg)' 
        : 'rotate(-45deg)';
    });
  };
  
  // Reset animation
  const resetAnimation = () => {
    const limbs = document.querySelectorAll('.arm-left, .arm-right, .leg-left, .leg-right');
    limbs.forEach(limb => {
      limb.style.transform = 'rotate(0deg)';
    });
  };

  window.addEventListener('scroll', () => {
    const currentScroll = window.pageYOffset;
    const scrollDirection = currentScroll > lastScrollPosition ? 'down' : 'up';
    
    // Calculate climber position (inverted for natural climbing feel)
    const scrollPercentage = 1 - (currentScroll / maxScroll);
    const climberPosition = 80 - (scrollPercentage * 60); // Climb range: 20% to 80%
    
    // Update climber position
    climber.style.top = `${climberPosition}%`;
    
    // Update altitude display
    const altitude = Math.round(scrollPercentage * 1000);
    altitudeDisplay.textContent = `${altitude}m`;
    
    // Animate climber
    if (currentScroll !== lastScrollPosition) {
      animateClimber(scrollDirection);
    } else {
      resetAnimation();
    }
    
    lastScrollPosition = currentScroll;
  });
  
  // Set initial position
  climber.style.top = '80%';
});
